Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

Marc by Sofia (2025)

Curious minds want to know... Documentary Movie collection.

Moderators: Maskath3, sidolanters, GabrielAlejo2341

Watch Docus Amazon   Docus Merchandise

Documentary movie collection.

Marc by Sofia (2025)

Post by bunniefuu »

-(insects chittering)

-(birds chirping)

(crowd chatter)

(whispering):

Going to Marc Jacob.

-(laughing)

-Marc Jacobs.



-Marc Jacobs.

-Marc.

This is Marc. Marc.

It's Marc Jacobs.

-Marc Jacobs.

-Marc Jacobs.

-Marc Jacobs. -Marc-Marc...

-Marc Jacobs.

...Jacobs. Marc's my friend.

Marc Jacob.

("100%" by Sonic Youth playing)

I can never forget you

The way you rock the girls

They rule the world

and love you

A blast in the underworld

But all I know

is you got no money

But that's got nothing to do

with a good time

Hey.







(song ends)

JIMMY FALLON:

Please welcome Anna Wintour

and Marc Jacobs.

-(applause and cheering)

-(band playing)

Fashion, fa... fashion.

-Marc, you-you share the couch.

-Oh, yeah.

Yeah, you'll be sharing...

sharing a chair

-this evening. Yes.

-Okay.

Welcome. Welcome to the show.

It's really wonderful

when you see someone like Marc,

whom I've known

for so many years

and-and seen him struggle

in the early days

and become such a success and,

I think, such an inspiration

to so many young designers

all over the world.

I remember my first cover.

You put...

It was Michaela,

an Israeli model,

and you put her in a yellow

and white dress of mine.

It was back in the days

of Perry Ellis,

and I was on the subway

going to work,

and someone said to me,

"You've got a dress

on the cover of Vogue.

What are you doing

on the subway?"

-(laughter)

-JIMMY: They want you to take

-a horse and carriage? Yeah.

-I was like, "Well..."

(applause and laughter fade)

MARC:

I mean, for-for me,

there's just so, like,

so much fear in starting.

Like, again, it's like,

I guess, a blank page.

And it's just like,

I guess, for a writer, like,

"What do you write?"

And for a musician,

"What do you, you know, sing

or write in music?"

(talking indistinctly)

-MARC: All right, what have

you got? -ANNA: All right.

-So you're looking at the...

-Needle-punch?

...needle-punch first.

So we tried--

this is a Shetland yarn,

and this is cashmere.

-We tried...

-MARC: I love Shetland.

Can we get anything more in

the-- like, what gauge is this?

ANNA:

This is all 7 gauge.

MARC: Yeah,

maybe we should try a lower,

-like a 5 or a 3.

-Yeah, yeah.

Like, so it's more s-sweatery.

ANNA:

Yeah, sure.

More sw...

Yeah, so we can see

the stitch more

-and it's more...

-ANNA: Mm-hmm.

I was looking for something,

like, sheer,

but not polybit, not nylon,

nothing--

not really a synthetic.

More like a wool that was, like,

a fine gauge or a woolen nylon.

So something that looks

more like wool but transp--

Like, so maybe between

the size of the yarn, the gauge

and the, um, tension...

but some-somehow

-where we could get

a sheer feeling. -Right, right.

To, um...

To discuss...

...how nothing there is.

-Like... (laughs)

-SOFIA: The blank page helped.

The blank page...

-I feel for you.

-Yeah, it's...

No, it's just the way it is.

I-I mean, I do-- I have faith

that it will become something.

So like a good leather,

men's-men's leather belt.

-Like, not...

-(Anna speaks indistinctly)

-Not like a '90s Milanese belt.

-(laughs): Yeah. Okay.

-MARC: That's kind of good.

-ANNA: Nice.

I mean, if we could do it finer.

It's a little...

-I'd like it cleaner.

-Mm-hmm.

-Cleaner. Okay.

-MARC: Cleaner.

ANNA: Yes, so just maybe

too textured for you.

-And this is very...

-But, but...

ANNA:

But the hand feel is good.

These are from Enrico,

different weights.

So our objective was

to get a smaller stitch size

and to get more structure,

-ideally with more filler.

-JOSEPH: Yeah.

These are all 18 gauge

and they couldn't really add

much more filler.

MARC: With us,

like, we-we get to the place,

or I get to the place

where I'm sitting with everyone

and we're like, "Well,

we've got to do something,

we've got to make some decisions

about fabric."

And then there's just a lot

of different conversations

that go on through the process,

but I don't know

that-- I can't remember...

...a season or a show where we

were, like, from the beginning,

we knew what we wanted to do

and it was about

working towards achieving that.

ANNA:

Yeah.

(Anna chuckles quietly)

Okay.

Sure?

-Yeah.

-Okay.

("Smoke Gets In Your Eyes"

by The Platters playing)

MARC:

I think the reality

of, um...

putting together the collection

and, you know,

getting to the point

of the show is like... really

a series of ideas,

and some of them feel very,

very strong or interesting.

'Cause it's a, it is a process.

So it's like, you know,

for a few months,

like, all creative energy is

focused on doing this thing.

You know, there could be, um,

a movie night

with John and Rachel

that includes The Bitter Tears

of Petra Von Kant

and it's, like, the first time

I ever saw it

so it really visually

was so stimulating

and, like, the insanity of it.

There was so much-- it was

so loaded that it could--

like, of course it was

gonna be a part

of what we were working on.

I mean,

because it stimulated me.



This is the part

where we try to figure out

what the models will be wearing

on their legs.

-JOSEPH: Yeah. See, this

is just like... -(laughing)

So, there's either doing, like,

custom colors of a hosiery brand

that we found...

-ROMAN: Yeah. -...and then

we have to figure out

what degree of sheerness

or opaqueness we want

and then have the colors dyed

to our specifications.

Or there-there was a plan,

once upon a time,

to make them ourselves

with our knitwear factories,

which we really loved that idea,

but there's very boring

technical problems with that.

I mean, this was one of

the Alex Katz painting

that we were really into,

just how flat,

like, the black dresses were

on all these women.

-SOFIA: I love her.

-MARC: Yeah.

But this line, I just loved

the texture of the skin,

that it was very powdery

and flat and matte.

JOSEPH: So this is... this is

like mannequin leg, right?

This is our opaque,

much more opaque...

(Delilah giggling)

JOSEPH:

The...

(Joseph speaks indistinctly)

-MARC: Okay. Yeah.

-Right?

-SOFIA: It does look like

mannequin leg. -Yeah. -Yeah.

But is there a problem

with that one?

-JOSEPH: No.

-So you can dye that any color?

Yeah, it comes in white.

Yeah, so that's no problem

at all.

-The really opaque one.

-Yeah.

The real mannequin.

MARC:

Like, this is a toile

that Joseph made,

and it's, like, um,

-an idea, right?

-Yeah.

-But it will become a much more

sophisticated... -Right.

...interpretation of this idea.

You know, we're... continuing

to make clothes

and study clothes as the

fittings are happening upstairs

on the models and the castings

and the music and...

Like, so, it's just, like,

that's all happening

at the same time,

so, like, everything

is delivered...

It's, like, very last minute.

I look over my shoulder

at, like, other designers

and I think, like, "Well, the

reason their work is so strong

"and so good and...

is that they're so talented

"and they probably have it all

decided from the beginning

"and then it's about, like,

a really extraordinary,

"you know, um, execution

of a single thought.

"And if I could be like them,

this is the way

it would turn out, too."



(speaking French)



MARC: When I look at my heroes

in fashion,

like, if you look

at Saint Laurent

and, you know, if you read

the sort of history

of, like, that, like,

Ballet Russe collection,

which was so extraord--

like how it was, like,

in this fever of the night

that, like, you know, he draped

all these fabrics on the stands,

or-- I think it was that one

-that he did that for.

-SOFIA: Oh, wow.

MARC: I don't know,

I can't remember what,

but it was one of his,

like, legendary collections

that apparently...

You know, and it was just,

like, a night of sketching

and, like,

fabrics all over the...

And, it's like,

that's what I want.

Like, you know,

but it's just not our story.

SOFIA:

Yeah, it doesn't have, like...

("Cavern" by Liquid Liquid

playing)

(low chatter)

-Now, this, that cut

generally fit... -Yes.

The fun part is how the hell

do we fit this sleeve,

-this super wide sleeve...

-Okay.

'Cause, see, I don't want it

going into a narrow...

Ah, the top.

It can't be na--

It's got to be large,

the top of the sleeve head,

you know, the sleeve.

-Ah.

-So the body itself...

-Uh-huh, uh-huh.

-...has to be wide up here.

-Yeah, yeah.

-So we're gonna have to do

this very kind of wide arm part.

-Uh-huh, uh-huh, uh-huh.

-Because most of the sleeves,

-they hang like this, right?

-Yeah, I know, it's collapse.

-Exactly. Ah.

-But what we want

-is to see this width up there.

-Yeah, yeah, yeah, yeah.

-So you just, from the side...

-Side.

-...you've got all this tipping

that way... -Mm-hmm.

-...and these tipping this way.

-Mm.

MARC: Interesting little

backstory about this.

-SOFIA: Yeah?

-This was a brocade we developed

once for a collection

a long time ago--

we never used it--

but it came from...

There was

an auction catalog that had

one of Elizabeth Taylor's suits

and it was done by Chanel for

Elizabeth Taylor in a brocade.

So we developed basically

a pattern inspired by that suit.

And then this season,

we were talking about,

like, having a gold brocade,

and we're like,

"Oh, well, let's look at

that pattern again,"

and we just blew it up.

We made it bigger

and then more like,

-with more relief.

-JOSEPH: Yeah.

And then the volume

of the fabric is a little bit

more exaggerated, so...

what goes around, comes around.

SOFIA: I like the whole

"all roads lead to Liz."

-All roads. I mean, always.

-(Sofia laughs)



Aren't you happy with me?

Happy?

Trouble is, I'm too happy.

MARC:

These are brooches from

-the Elizabeth Taylor jewelry

collection. -(Sofia laughs)

And I just felt very...

There was that quote

by Andy Warhol

when they asked him

what he'd want to come back as,

and he said,

"I want to come back

as a diamond

on Elizabeth Taylor's finger."

-I never heard... -And I just

thought, like, "Oh, wow," so...

But, I mean, it wasn't

because of that quote,

-but the quote came to mind

when I... -Yeah.

We were researching

and looking at jewelry,

'cause I like this idea

of the patch,

but, um, then I just thought

it needs to have

some kind of sense,

so I thought, like, right,

Elizabeth Taylor's jewelry.

SOFIA: I can't wait to see it

all come together.

-MARC: Me, too.

-(Sofia laughs)

(blow-dryer whirring)



MARC: We got very playful

in the fitting room one day

and we were just, like, stacking

wigs on top of wigs and,

-you know, like you do.

-(Sofia chuckling)

And, um, I sent the pictures

to Alastair,

and he was like,

"Oh, I love it."

So we were talking about

how serious that was.

Like, maybe would we do that,

would we not do that?

The pluses and minuses

of doing something theatrical

and how that's entertaining

or keeping it more real

and more about, like...

Anyway, so we went through

all of those aspects?

-Yeah. We did.

-Right?

And... we have not come

to a conclusion.

SOFIA: Are you leaning one way

or the other, or you're...

We're leaning towards

entertainment.

-Entertainment and joy.

-(chuckling)

Hello, Dolly

Well, hello, Dolly...

MARC: I went to the opening

night of Hello, Dolly!

That was my first movie

in a theater.

Back where you belong...

SOFIA: Why do all g*y men

love Barbra Streisand?

MARC:

I don't know. Like...

I love Barbra Streisand.

But I-I don't know what it is.

Wh... It's a really...

That's a really good question.

But I guess there's something,

I don't know if it's the nails

and the long finger

or if it's the whole, like...

I mean, I-I don't know.

But it's not only

Barbra Streisand.

-It's like, Barbra Streisand...

-SOFIA: Liza.

MARC:

...Liza Minnelli,

-Diana Ross...

-Yeah.

...is a big one for the gays,

I think.

SOFIA:

Yeah, glamour.

MARC: Yeah. But I think

there's just a theatricality.

When you look at those women,

they're so much

like a caricature of themselves,

you know, and they have that--

-Joan Crawford's another one.

-Oh, yeah.

You know, there's like that

caricature, camp.

-Camp of womanhood. Yeah.

-(Marc laughs)

Well, all the odds are

They're in my favor

Something's bound to begin

It's gotta happen

Happen sometime

Maybe this time

Maybe this time I'll

Win.

(song ends)

I don't know when the first time

I saw Cabaret was.

Uh...

But it was...

I'm-I'm pretty sure

it was Cabaret

that made me fall in love

with Bob Fosse

and then want to see

Damn Yankees,

and then want

to see Sweet Charity,

and then want to see,

like, everything that Bob Fosse

ever did.

SOFIA: I feel like

all his movies were great.

MARC:

Yeah. He's just a great...

-And All That Jazz.

-All That Jazz.

Great mind.

("On Broadway" by George Benson

playing)

They say the neon lights

are bright on Broadway

They say there's always magic

in the air...

MARC: I think somewhere

in another life

I really want to be, um,

a theater director,

or something like that.

I don't really,

but I think this...

this has a very,

like, doing the fashion thing

is just very linked,

it's the same kind of process:

the casting, the music, the set,

the costumes.

Like, only in fashion,

you get to do all of it.

(vocalizing in song)

The set design was inspired by

this Jeremiah Goodman painting

of Diana Vreeland's apartment,

Garden in Hell.

On Broadway

Looking at them

just gives me the blues.



("Funky Boss" by Beastie Boys

playing)

MARC:

I loved, um...

you know, I loved

back-to-school clothes.

SOFIA: How young were you

when you were starting to think

about your back-to-school look?

MARC:

I-I have...

I have it in my mind, like,

eight or nine, but, um...

I think I was very influenced

by teenagers I saw at the time

who, I think one of them

was a babysitter,

and, um, she--

the babysitter and her friends,

you know, were probably 18, 19,

and they were wearing,

like, flared jeans

and they had, like, you know,

they had, like, their...

teenage hippie vibes or whatever

was going on. (laughs)

Like, early '70s.

And I just looked at them, and

I thought they looked so cool

that I wanted to look like them.

You know, like, at my young age.

("The Candy Man" by Cibo Matto

playing)

(vocalizing)

SOFIA: Did you ever think

as a kid that you would have

your salon at Bergdorf Goodman?

(Marc laughs)

MARC: No. I mean, it is funny,

the Bergdorf Goodman thing,

because I remember going there

with my grandmother.

And my grandmother was,

like, really fashiony.

She really loved clothes.

She was of a generation

where there was,

like, a great,

like, respect for clothes

and also what was appropriate

for certain things.

So she had subscribed

to that notion that gloves,

like, leather gloves,

were either black or white.

Like, you just didn't wear

colored leather gloves.

(laughs): Like, I don't know

where that came from.

-You know, so...

-(doorbell ringing)

SOFIA: Is that where

your sophistication,

your taste, comes from?

-And, like, you know about

stuff. -I think it came...

-Appreciation definitely

came from... -(door opens)

I used to go shopping with her,

and I used to, I just loved it

when she'd have the beauty

parlor appointment on Friday,

and then she'd go to Bergdorf's

which was down the block

from the salon

that she went to, and...

You know, and I think,

I think I saw...

or-or saw, like, beautiful

or more luxurious clothes,

you know, with her.

And she was also very...

like, she didn't have

a lot to do, so,

like, during the week,

her outings to different places

were very, like,

that was what her-- she did.

So, like, Bonwit Tellers

was on a certain day,

and Saks Fifth Avenue

was on a certain day,

and Bergdorf was the day

of her salon, so she would buy

certain things from certain

places. Like, she's be like...

-SOFIA: She had a schedule of...

-(chuckles)

She... Yeah. She'd, like, plan

her day around that, so, like,

then you'd know what restaurant

she'd eat at for lunch,

or where she'd... Like,

if she was at Lord & Taylor,

she'd go to the Bird Cage,

and she'd have chicken salad.

Like, everything was very set.

("Heart of Glass" by Blondie

playing)

-SOFIA: Hi.

-Morning.

Good morning.

(continues indistinctly)

Once I had a love,

and it was a gas...

Maybe back there.

Let's do Marc's office.

Had a heart of glass

Seemed like the real thing,

only to find

Mucho mistrust,

love's gone behind

In between

What I find is pleasing,

and I'm feeling fine

Love is so confusing,

there's no peace of mind

If I fear I'm losing you,

it's just no good

You teasing like you do.

-(Sofia chuckling)

-ROMAN: That's good.

Go to the other side.

Sort of come around

-and we can see you better.

-SOFIA: My cameo.

Yeah.

-SOFIA: No? -ROMAN: It's

upside down, but it's okay.

SOFIA:

But-but the words are...

Okay, then that's

more important.

(Roman and Sofia chuckling)

One of my favorite outfits is,

it was Halloween

and I didn't have a costume

and Marc brought, got...

-And Andrew.

-Yeah, and Andrew.

We were all having Halloween

and you brought me, um,

-a boy's cop uniform.

-Police... Yeah.

But it fit me. It was so chic.

-Like, it fit me perfectly.

-Yeah.

I was like, of course, that was

one of my favorite Marc outfits.

ROMAN: How-- I'm gonna ask

two questions.

How long have you guys

known each other?

When do you remember

first meeting Sofia?

-SOFIA: Uh, at, um...

-MARC: Perry Ellis.

SOFIA:

At Perry Ellis.

-Yeah.

-Like, it was '93?

-It was...

-Or '92?

-It was grunge.

-It was grunge,

-and we were in New York.

-Yeah.

And I asked Mom to take me

to see your collection.

But I don't... I-I must've

seen it in a magazine.

Was it in Vogue or something?

I-I don't know

how I knew about it

'cause there was

no Internet then.

I don't know.

Well, 'cause it's you.

-I know. -You know about things.

That's how.

SOFIA:

I was excited. I was, like,

-early 20s.

-New York was a small place.

Sofia and Spike. This is Spike

Jonze,

video director extraordinaire,

Dirt magazine editor.

And Sofia Coppola, photographer,

fashion model,

they came up to us and said,

"We want to do a fashion show,"

and we were like,

"Great. Whatever."

And then six months later,

-they were really serious

about it. -Yeah.

And then we all four got

our heads together,

and the rest is history.

INTERVIEWER: You guys kind of

came up with the idea

of, like, how the fashion show

is gonna look

and where it was gonna be.

How'd you come up

with that idea?

SOFIA: Well, because

it's, uh, Fashion Week,

we wanted to do it in New York

in the middle of the whole

traditional Fashion Week.

And, um, our friend Marc Jacobs

just had a show down the street

so we figured

while everyone leaves that,

they could come check this out.

I just thought it'd be fun

to do a fashion show,

um, but I-I never designed

a line of clothes, so

we were just talking about

doing a outlaw fashion show

to liven things up this week.

(punk music playing)

KIM: You know,

it's sort of like your dream

is always to wake up

in the morning and be able

to reach in your closet,

half asleep,

and just put on something

that's gonna, like, fit

and look fabulous and you don't

have to think about it.

MARC: When you think Milk,

right, or X-girl

and you think about, like,

the perfect baby tee,

-or whatever we called it

then... -Yeah.

...you know that

little perfectly, like...

If you, if you just

imagine, like,

what somebody else

would be like,

"What, what are they making

such a big deal about,

-like, a T-shirt?"

-SOFIA: Yeah.

MARC:

But I remember, like,

Kim Gordon and Daisy...

and they'd be like, you know,

they-they were so precise...

-Yeah. -...about how

that miniskirt had to fit.

-

-MAN: Yeah, baby.

RITA ACKERMANN:

And the world

currency markets

will never lose faith

in the deutsche mark,

the dollar...

I'm exhausted.

I will never catch up.

CHLO:

So what's up with Salinas?

-Jackie Joyner-Kersee.

-(blows raspberries)

-Elizabeth Bishop.

-(blows raspberries)

Brigitte Bardot.

When you look back at

a lot of those images now--

like when I look at, like,

Chlo Sevigny and stuff--

it's like a lot of those images

really kind of hold up

-in a way because...

-Yeah.

They... it was a kind of

iconic moment.

WOMAN:

Would you rather sell beer

or drink beer or make beer?

I'd rather sell the beer.



-WOMAN: Hello. How are you?

-CHLO: Hi.

CHLO:

I'm okay.

-Who is this? -Do you have

a Guy Lyonais that checked in?

WOMAN:

Can you spell the last name?

CHLO:

L-Y-O-N-A-I-S.

WOMAN:

Excuse me, miss.

Do you know a Guy Lyonais?

Some of the dresses looked

a little stewardess, 1973,

serving your drink.

MAN: Stewardess?

I thought they were, like,

factory worker, 1973.

Factory worker, stewardess,

-working-class woman...

-Yeah.

...but with the svelte body.

It's just working.



WOMAN: There's Jules Truman.

Jules Truman.

-I got it.

-Because...

he has to get the show started,

and I can't deal with it

anymore.

(indistinct chatter)

("Dirty Boots" by Sonic Youth

playing)

This is crazy. This is really...



-Do you know Guy Lyonais?

-Who?

-Guy Lyonais.

-No.



KIM GORDON: This is one of

my favorite dresses

that I ever wore onstage.

It's a Marc Jacobs dress,

and you can't tell

from this picture

but it's got all these sequins

on it and...

it was almost like being

a disco ball.



MARC: Way back, I met this guy

named Nick Egan.

Nick Egan was very close

to Malcolm McLaren

and, um, Vivienne Westwood

and-- well,

particularly Malcolm McLaren--

but fast-forward many years

and it's the grunge collection

at Perry Ellis,

and, um, Nick Egan calls me.

And I hadn't seen or heard

from him in a long time,

and it was like,

"Marc, it's Nick."

And I was, like,

so happy to hear from him.

And he's like,

"Listen, I'm directing, um,

a video for Sonic Youth."

And I was like, "Oh, my God,

that's so amazing."

I was like, "I love them.

They're great."

And he's like,

"Well, I had this idea

which I presented to them

and they were really into it."

He was like,

"Could we get together

and would you be willing

to meet Kim and Thurston?"

I, like... froze.

I was like, "I-I don't know

how I can meet Kim."

Like, it was

so intimidating somehow.

-SOFIA: Really? Why?

-Yeah, I felt...

I-I've always been--

I know it doesn't

come across that way--

but I'm-I'm pretty

uncomfortable socially,

and I am very intimidated

by people I look up to.

You know, it's just, like...

And-and I, I thought

they were just so cool.

Like, there was, like,

"How am I gonna...

"You know, how am I gonna

bring my little, like,

"designer chops to the table

with all that coolness

of Kim Gordon?"

("Sugar Kane" by Sonic Youth

playing)





MARC:

I-I sort of felt like

it was in a bit of a weird

situation, 'cause I felt like

I was, like, doing

that grunge collection,

that it was looked down on

by, like, Courtney and Kurt

and people like...

-Oh, as a poser?

Or commercializing? -Right.

So, so, I kind of felt like,

"I would love to do this,

but I don't want to be

the butt of your joke."

Oh, right.

MARC:

I mean, it's really interesting,

like, when you look at, like...

There were so many negative

reviews and, like...

-SOFIA: Really?

-Oh, yeah. And then,

of course, the evidence

of how important it was

is still everywhere you look.

It was all... across all genres.

-It was like you had music...

-Yeah.

...fashion, art and photography.

So... you know,

there's all of those things

were just undergoing

this change.



(music stops)

-MAN: Nice to meet you, Marc.

-MARC: What's your name?

-I'm Ian.

-Ian. Hi, Ian.

-You wrote your question down?

-I did.

-I wrote my question down.

-(chuckles): Wow.

(laughter)

Um, so I have...

I kind of have two questions.

-Okay.

-Um, one of them is--

I'm at Parsons right now--

um, so I was wondering

how art school

kind of informed your career

and how you feel like

that was valuable to you.



EMCEE: And next,

a trio of fabulous sweaters

by Marc Jacobs.

Hand-knit, of course,

supersized shapes

over jersey tops

and flannel bottoms.

MARC:

I loved my school years.

I mean, I worked

really, really hard.

EMCEE: Fabulous patterns,

fabulous color.

And that extraordinary trio

has earned Marc Jacobs the

Perry Ellis Gold Thimble Award.

MARC:

Some of the teachers at Parsons

would tease me and say

that I was very jaded,

but I grew up in the city

and I didn't feel

like I was jaded.

I just felt like I was

experiencing as much as I could,

in and out of school.

And so, um, sometimes school

would be frustrating to me

because I would think,

this isn't helping

train for real life.

Like, real life is happening

outside of school.

(applause)

EMCEE:

Don't go away, Marc.

Because Marc Jacobs

was also voted

the Student Designer

of the Year award.

(applause)

MARC:

All the students, um,

were broken into groups

by designers.

So you'd have different

designers come into the school

and they'd be given, like, ten

or-or whatever, eight students,

and I was in

the Perry Ellis group.

I remember I showed him

my sketches

and he was very impressed.

And he had-- I'd met him before.

I met him when I was 16

at Charivari.

When Charivari opened, he was

there with Jed and Patricia,

who were his two assistants

who both went to Parsons.

And it was he who told me

if I was serious

about being a designer,

I should go to Parsons

like his two assistants.

And so I had these illustrations

that were two or three figures

on the page.

So the one he chose,

he was like, "Well, you can..."

He's like,

"I love any one of these.

Which one do you want to do?"

And I was like,

"Well, I have to do all three.

It doesn't make sense

just to do one."

And he was like, "I don't know

how you're going to finish one,

"let alone three, but if

that's what you want to do,

go for it, you know."

So I graphed out

these sweater designs.

They were, like,

these geometric designs,

and I graphed them out

on graph paper

'cause I kind of understood the

principles of, like, knitting

after watching my grandmother.

She had taught me

how to do knit...

You know, she taught me

how to knit

and to do needlepoint,

and-and she actually knit

the samples.

SOFIA: And the ones

that you had at Charivari,

-were those she actually made?

-So...

so, so, I showed those...

I mean, I made all the clothes

that went with the sweaters,

like, the skirts and the pants

and the, the layering pieces,

and I showed them,

and then Barbara Weiser,

who was from Charivari,

who I'd become

very friendly with,

she saw my work in that show

and she said, "I would love

to produce these sweaters."

MARC: And then in order

to make fun of the polka dots

and to make them

even less serious,

and what I think is...

is and always will be

a wonderful image,

is the smiley face of the '70s

because people can't help

but smile

and sort of laugh

when they see it.

It's, it's, uh, you know,

it's really a pop icon

and it's something that'll be

around for a long time.

And then with the sweaters,

we did opera length... mittens.

These are mittens that are knit

past the elbow, and again,

I put little smiley faces

on the palms of the,

of the, uh, mitten.

So that was my first

commercial venture,

and the label said, "Marc Jacobs

for Marc and Barbara."

("Hey! DJ" by The World's

Famous Supreme Team playing)

Hit it

Huh

We would like to dedicate

this record

To all the DJs

in the entire world...

INTERVIEWER: I know you and Marc

really go way back.

What is it about

that camaraderie?

I mean, why is it so important

to have that support

from your peers?

Well, thank God there's Marc.

-I mean, you know...

-Yeah.

It-It's like...

I-I think that, um,

it just makes

New York much more exciting.

ANNA SUI:

One night, it must've been 1981,

I saw him at Danceteria

on the dance floor.

After that, I became, like,

very aware of Marc

and, like, his style,

and then all of a sudden

he was the news

with his Sketchbook collection.

Hey, DJ, just play that song,

keep me dancing all night

Thanks, girls, now thank DJs,

MCs, cable TV

And radio station

personalities

(fading): For the new tunes

we hear today...

(low, indistinct talking)

SOFIA: The grunge collection

wasn't the first thing

you did with Perry Ellis,

was it?

MARC:

No, it was the last.

-Oh, yeah. Did you get fired?

-(laughs)

-Did you get fired?

-No, that...

-It's a misconception...

-Oh.

-...but I really like,

I like it. -Yeah.

You know, I like that, like,

-"Oh, I did this collection...

-So scandalous.

"...and I got fired for it

and it was, like, you know,

and I was so young, and

I was fired," and duh, duh...

But it isn't really the truth.

-But I mean, it's-it's the story

I like to go with. -Right.

But why was the collection,

like, scandalous?

It just seemed like that's what

people were... I don't know.

-I was excited that it was...

-I guess people were

very easily...

easily scandalized.

-I mean, why...

-You're rocking the boat.

You know, I don't know

why Saint Laurent's, like,

Forties collection

was so scandalous either.

SOFIA: Yeah, it was called

The Scandal Collection.

I don't get that.

Oh, because it was

too close to the w*r.

MARC: Yeah, but when you look

at those clothes,

does it really look

like wartime clo--

It didn't-- like, I-I get it.

It's, it was a really

great look,

and I think that moment

in the '70s where they embraced

the '30s and '40s,

-like...

-That's my favorite, too.

MARC:

...the chicest thing.

("A Whiter Shade of Pale"

by Ronnie Aldrich playing)



MARC:

Interior-wise,

clothing-wise, like,

I just feel like

so much stylization,

like, through the '70s lens,

-that stuff just looks

incredible. -SOFIA: I know.

It's the best.



MARC: I guess, I guess

it's like everything.

It's all... relative, right?

So, like,

what was happening in fashion

and, like, how women looked,

how they were photographed,

what kind of clothes they wore,

you know, like models,

and then all of a sudden

there was this shift

with Corinne Day

and Juergen Teller, David Sims,

and it was all about, like,

you know, Kate Moss

in a pair of panties

with, like, some fairy lights,

you know, like...

I think women couldn't

become that.

Like, they couldn't take that

picture to their hairdresser

and say, like,

"I want to look like this."

-Oh, right.

-Do you know what I mean?

It was like an unachievable...

beauty.

And then, you know,

look at Courtney.

Like, you know, here was

this really strong woman,

and, like, she... her hair

was fried and bleached,

and, like, her lipstick

was all over her face,

and she was wearing a torn dress

that was about five sizes

too small.

I think that was part

of the scandal, was that

it was just, like, so shocking.

The thing that scares people the

most is, like, anything natural.

You know,

because they can't aff--

-It's just hard to affect,

right? -Oh, right, right.

SOFIA:

Tell me about Cindy Sherman.

MARC:

She's great.

Cindy's great and so inspiring.

This idea of, like,

inventing yourself

and, um, make...

creating this character,

this cinematic character, and,

like, she made that her art

and then did it

so, so perfectly.

It was the Film Stills that

were the first body of work

of Cindy's that I knew of

and that I fell in love with.

And I think

it's almost so clich

to be a designer and say, like,

"Oh, Cindy Sherman's

Film Stills,"

'cause, it's, like,

it's a go-to.

You know, it's like saying

Audrey Hepburn

in Breakfast at Tiffany's.

It's like, Cindy Sherman

in Film Stills.

Let's open this up

and just sew it on

-a little more softly.

-ANNA: Mm-hmm. Yeah.

-Uh, instead a little nailed

down here, right? -Right, right.

Just want to make sure

it stays there, okay?

So it's just, like, all

the styles that are happening.

So everyone knows

what's going on.

SOFIA:

Oh, cool.

-This is what they're working on

now? -JOSEPH: Yeah.

So, these are, like,

the sequin dresses.

I, you know,

the different, like...

So I've made the first one,

the second one. Like, we want...

SOFIA: Are those gonna get

sequins added to them?

No. These are just

to check and shape by it.

So is it just toile

in that kind of fabric?

Yes, yeah, exactly.

I think the future of fashion,

the future of the world is about

not living by rules

that were established

30 years ago

but by doing

what's right for you

and respecting the things

around you.

And I-I don't mean to get,

like, too philosophical,

but I think that I do what I do

and somebody down the block

does what they do,

and we can all do our own thing,

and girls can wear

what they want

and when they want

and how they want.

I'm hoping, in the future,

that people stop labeling things

like '60s or '70s

or this or that,

because all

of these things exist,

and they, to me,

they're all classics, you know?

And I think

we use natural fabrics

and we make, I make the clothes

that I like at this moment.

I show things in a certain way

to project a spirit,

but I don't expect people

to copy

what I've done on the runway.

I think that if you like a shirt

you see on the runway,

then you buy a shirt-- you don't

need to buy the whole thing.

And if you like the outfit,

you should make it work for you.

You know what I mean?

Not everyone is gonna look good

in a long skirt or a short skirt

or a sheer skirt.

So you choose

what's right for you.

You should never listen

to a designer,

especially a man designer.

I mean, I can't wear

these clothes.

It doesn't matter.

You know?

It's just a fantasy for me.

("Little People (Black City)"

by Matthew Dear playing)

SOFIA: When did you start

doing Louis Vuitton?

MARC:

1997.

Oh.

And Perry Ellis was over

in 1993. Right?

And then there was a year off,

which was '94...

So '95 to '97,

I was doing collections

with Robert over there.

SOFIA:

Oh. And then,

they didn't have clothes

at Vuitton before...

-You had to...

-No, they never had anything.

Just bags and luggage.

SOFIA: Was it hard

to make that different

than what you were doing

at Marc? Or, like,

-did you get a different

frame of mind? -Yes.

-Or was it really...

-Yes and no.

It-it seemed... it seemed...

like, really impossible

to make it different,

but then,

I think there was one day

where I came to this realization

that as soon as

I get on the plane

and go to Paris,

it's automatically different.

Like, I could,

I could say, like,

I love a black T-shirt

in New York,

and I know that what that

black T-shirt would look like

and what fabric it would be in.

But if I say I love a black

T-shirt, once I go to Paris,

I know that it would be,

like, super finished,

it would be this,

it would be that.

It would be a different

black T-shirt, so

I did, I did come

to that realization

that, like, I could love

the same thing

but in two places

it will be two different things.

("Sept heures du matin"

by Jacqueline Taeb playing)

(song continues with lyrics

in French)

(scatting)

WOMAN: I really think about

your time at Louis Vuitton

and a lot of

those collaborations,

like, with Pharrell,

for example,

and I feel like

those are people that

are maybe not necessarily

thought of within the context

of a luxury brand like that.

So, did those collaborations

feel risky at the time,

or how was it experiencing

those with them

and bringing them into something

like that?

Hmm. Um...

I... honestly didn't...

This is... I didn't really

overthink, think them.

I thought it was great

that Pharrell

was interested

in making sunglasses,

and I was like,

"Yeah, come on, let's do it."

Like, I really didn't

overthink it.

I have gone from a place

at Louis Vuitton

in the beginning

where I was trying to be,

you know, a good soldier

and please everybody,

and then I just kind of

got fed up and it was like,

"You know what?

That's not what I'm here for.

I'm here to... to be creative."

So I wanted to work

with Stephen Sprouse.

I wanted to work

with Pharrell.

I wanted to work with Nigo.

Whatever it was, I just said,

"We're going to do it."

What's really interesting

is that now

some of those people

who were so resistant

now are saying, you know,

how great certain things were,

and it's just like,

when, you know,

and I roll my eyes in my head,

and I just think,

like, "Ugh, they were all

arguing against this,

and now they all think

it's, like, the greatest thing."

But whatever, that's sometimes

the way life is.

Under the tutelage of Marc,

I mean, you know,

he-he's an amazing guy.

He's been so gracious

and so generous

and-and with-with, uh, his

intelligence and his direction.

The greatest taste,

greatest designer unto yourself,

greatest taste

and people that you have

and would like

to collaborate with,

I mean, just like GOAT,

GOAT, GOAT level.

-GOAT level.

-(Marc scoffs)

-Thanks. -Like-like, people know

who Murakami is.

He has a really incredible,

you know, portfolio.

Man, when you gave him

that platform

to do what you guys

did together,

it was like a magnet

for so many of us who were

watching the brand, like...

we're like, "Okay,

Vuitton is a different place."

("Kiss and Tell" by Bryan Ferry

playing)

MARC: For me, collaborating with

artists of different types--

musicians, contemporary artists,

um, actors--

we all share that passion,

which is the idea of creating

something, changing something.

And that's very exciting.

Looks like, uh,

the kind of new era

because the art become to

the exactly the entertainment.

Like, you know, the first time

people mention for the

correlation with fashion

and art,

but maybe in the near future,

they see the, you know,

the kind of,

uh, new entertainment.

("Veridis Quo" by Daft Punk

playing)

Oh, I thought the show

was beautiful and exciting,

and I loved the Richard Prince

naughty nurses.



There was some really great, uh,

French punks in the art world.

You know, Duchamp was, like,

the ultimate punk rock artist,

and that was part of

what I thought about

when I came here.

This is like so much

of French culture.

It's, like, in order to, like,

in order to change something

and in order to make it cool,

like, you have to deface it.

Like, you have to show it

no respect.

You know, like, and so,

so that thinking

kind of brought me

to the idea of graffiti or

defacing this, like, you know,

"You can't touch

the monogrammed print.

It's sacred," and duh, duh, duh.

I was like, "Yeah, we should

just write all over it."



SOFIA:

Were they like, "No, you can't"?

Yeah, they said,

"No, you can't." (laughs)

And then how did you

push it through?

Well, then they said, like,

"Well, you can do it, but

we're not going to produce it."

And then it kind of blew up,

and then, like,

everybody wanted it,

and, like, people were calling

and saying, "When can I get it?"

And the stores were take...

There were, like, waiting lists

for these bags that they weren't

planning on producing.

And, um, and then

all the counterfeiters came out

with them, and so, like,

they were appearing everywhere

whether they wanted to or not.

("Love to Love You Baby"

by Tom Tom Club playing)

I...

GRACE CODDINGTON:

I-I think along the same way

as-as he does.

I mean, he always has

a romance to his clothes

and things that I've always...

And I'm kind of romantic,

too, so...

So I-I go towards that, um...

So I think, uh,

I want to say it was

love at first sight,

-but...

-(Marc laughs)

I love to love you, baby...

GRACE: And I've seen just about

every Marc show

since he began, I guess.

I'm a huge fan, and I-I'm a

huge fan for a very good reason

in that I think, you know,

he's quite remarkable.

I-I don't know,

somehow he always hits it

on the head for me.

SOFIA: I like

your ladylike version, too.

MARC: There's a lot of

ladylike stuff.

Having dressed Winona

for her trial.

(chuckles): Having dressed

Lil' Kim for her trial.

You know, and they...

and then it's like,

as soon as they need

to put on this kind of

image of propriety--

-the Winona ones are close

to classics. -(Sofia laughs)

I think I'm gonna always

look at it as a costume

-because it-it just feels like

it belongs... -Yeah.

...to somebody

who's got maturity

-that I don't, or that...

-That's so true.

...you know, that belongs

to another time.

-"Go to Marc." (chuckles)

-Yeah.

"He'll dress you

for your trial."

MAN: Courtney Love,

is it true that, in 1993,

did you offer Eldon Hoke $50,000

to m*rder your husband

Kurt Cobain?

Oh, God, Richard Lee.

You suck so bad.

("Sugar Water" by Cibo Matto

playing)

The velocity of time

Turns her voice into

Sugar water



(vocalizing)

(speaking French)

-(laughing): Wow.

-(others exclaiming)

Look at that.

That is so insane.

That is sick in the head.

(vocalizing in song)

MARC:

This is so nuts.

The buildings are changing

into coconut trees

Little by little.

(song fades)

MARC: In talking about what

we were making with clothes,

let's see it blown up, you know,

Joseph was like, "Let's just

see it blown up really big

"and see how we feel about it.

Or let's see it really flat,

you know."

And either one of those things

would bring the approach

to making the bags in line

with the approach

to making the clothes.

There's a leather

mock-up that...

I mean, they did a leather

prototype from this mock-up.

-Yeah.

-It was, uh... And then...

-WOMAN: It went to the factory.

-SOFIA: Oh.

WOMAN:

Yeah. To get...

-JOSEPH: Made?

-Made. -Yeah.

SOFIA: And when does that stuff

all show up?

When's that show up? Uh...

-Two days before the show.

-WOMAN: Yeah.

SOFIA:

Is it always nerve-racking?

-WOMAN: Yes.

-(laughter)

Always.

("Reminiscences" by Nigel Hess

playing)



(music ends)

It needs to be like dead Barbie.

(chuckles)

Not pink enough.

JIN:

Okay, hers is okay.

MARC:

Um, what length are you...

Can you cut the girls nails,

or no?

JIN: Just reg...

So their-their length.

-Short. Short, yeah.

-MAN: Yeah, short.

MARC:

Sh-Short, but...

Short like boyish short

or girlish short?

-Like...?

-JIN: Round short.

-MARC: Round short like that.

Okay. -JIN: Yeah, yeah, yeah.

-Not, not too square.

-MARC: No.

-No, it's too bright.

-JIN: No?

It should be a,

it should be that but pink.

Oh, hello, Mr. Nimmo.

NIMMO: Um, what do you actually

sell here?

VIVIANNE:

Um, clothes.

These, uh, cardigans you can

see through, sort of woollies.

VIVIENNE: Mm. These restrict

your arm movement somewhat.

So you're really caught

right down there in bondage.

Yes, but it's...

But to move in that

has a lot of style and flair,

because as you move,

you can sort of see through

some of the...

-No, when you wear this...

-Yes.

...you can see

sort of, you know,

a body here with bits

of lacy stuff in between...

MARC:

So I just became

completely, like, obsessed

with Vivienne Westwood.

I'd known of her and Malcolm

as being the designers of

Sex and Seditionaries

and, you know, kind of defining

what punk looked like in London.

I was just fascinated by her

and by what she did.

Just thought it was, like,

style with substance.

It felt like there was a thought

process behind the style,

as opposed to just

arbitrarily making some,

you know, weird clothing.





MARC:

And then I got to meet her and

we bonded over, actually,

Yves Saint Laurent.

It was the weirdest thing.

So, she was having a show

at Bergdorf Goodman...

and they invited me,

she and Bergdorf invited me

to join this dinner

after her show at Bergdorf.

And I was seated

next to Vivienne at the table.

And Vivienne, you know,

had a reputation for not...

If she didn't like you,

she made n--

Like, she had no problem saying,

like, "I'm not int--"

Like, she didn't make

polite conversation,

and she was not, like,

she didn't suffer fools.

SOFIA: Were you nervous

to sit next to her?

A little bit,

a little bit. Yeah.

I was, I was intimidated

and a little nervous.

But we both drank a lot

of red wine at this dinner,

and everybody-- eventually,

we were the last two people

at the table.

And then we got into

this conversation about

a mutual love

of Yves Saint Laurent.

I don't know how

this happened, but...

And she, I remember she said,

like, "Don't tell anybody."

Like, like, it was a secret.

Like, she knew

about Saint Laurent

and I knew about Saint Laurent,

but don't let

the others know about him,

you know, like...

It was a very... it was

a very sweet and strange thing.

Like, they've not discovered the

genius of this man, but we know.

(low conversations)

MARC:

So, this elastic

is only this high.

It's like three... quarter

of an inch, or something.

I just... are we gonna want this

to feel more flat?

We're getting a, um, the elastic

-in the right size.

-Oh, a deeper elastic?

-Okay.

-Before the show's happening.

But, but the point,

the rib would be...

MARC: I remember one of

the discussions was, like,

this fabric that we've used

before that was very rounded,

it was, like, a '60s fabric

that's bonded to itself

and there's one Italian mill

that made it back in the '60s.

And I used it for us

and at Vuitton,

but it's very round.

It doesn't collapse.

So when Joseph said, like,

"Maybe me a pair of shorts,"

it was, like,

it wasn't so much that I was

crazy about the idea of shorts.

I just like the idea

of thinking about something

I wouldn't typically use

that fabric for.

We just laid these fabrics out

to decid-- pick colors

-for the sweaters to see what...

-SOFIA: Oh.

sweater top would go

with what leather short.

So, you can see over...

SOFIA: Are the big...

are the big shorts leather?

They are, yeah.

They're a bonded leather.

And so we just put a little

swatch next to all the colors

so we can kind of predict

what, um... the look will be.

MARC: We wanted to make them,

like, very naively.

Like, so, we thought, like,

"Oh, it should look like

you cut it out of fabric

and you sewed it together

yourself."

And so it had

no sophistication whatsoever.

I mean, not true sophistication.

We made this pair of shorts

with that kind of body,

and we were like,

"That looks really good.

We really like it."

Then we liked the idea of it

with sexy shoes

from the Trompe L'Oeil

collection,

and that was kind of

how it started

when we... when we both,

Jospeh and I,

had this immediate reaction

to, like, Delilah

in this red sweater

with these, like, weird shorts

and then a pair

of high heel shoes.

And we're like, "Yeah, that

looks like what we want to do."

(crowd chatter)

You know, we thought

we would see one body...

-ANNA: Right, right.

-...neoprene

and one body double knit,

and if we liked the double knit,

-that's what we would do

the group. -Right.

-You see? So we were doing it

originally... -Right, right.

...to see which one

we preferred.

It's tricky, 'cause I need

to order the panels.

-Well...

-For... So...

But if it's double knit,

you wouldn't be ordering

-a panel, would you?

-Exactly.

Right now, I'm planning for it

to be double knit.

But if you want to...

But only one body you're

planning to be double knit.

-WOMAN: Correct.

-ANNA: This style...

Right, the zip-up hoodie

is gonna be bonded.

Right. And what we were thinking

was we would choose...

There would be one thing

in the end.

-...and then you would do...

-Do one thing.

-Got it.

-So that, for us, is a test.

-I see.

-Yeah.

I remember, um, I had

a Groucho Marx T-shirt

that I was particularly proud of

that I wore with suspenders,

and it was pre-Mork & Mindy,

(laughing): but it was very

that kind of look.

But, um, yeah,

I had a, like, this--

I don't know what in the world

or where it came from,

but I was, like, really enamored

with this, like,

Groucho Marx T-shirt.

But I was pretty meticulous

when it came to clothes.

Like, I folded everything

perfectly.

I mean,

I folded T-shirts perfectly

and, like, all that stuff,

so I always made sure

it was on a good hanger

so the shoulders

didn't stretch...

Like, I... I had such

a relationship with clothing.

My first outfit that I ever made

was a blue,

like, a baby blue gas station

attendant jumpsuit.

And that was one of the things

that I thought,

like, I saw... I saw,

I mean, I must've seen,

'cause I don't know how

I would've gotten in my head,

like, "That's a cool thing

to wear,"

but there must've been

some grown-up kid

wearing, like...

and I feel like it had, like,

patches all over it.

Like, you know,

like a,

like a gas station attendant.

Anyway, I had it in my head

that that was, like,

the cool thing and that

the only way I was gonna get one

is if I learned how to make it.

So I had, like, a home ec class

where we learned to sew,

and that was the first thing

I-I sewed.

-JOSEPH: How's it going,

over here? It's okay? -Good.

-Yeah, yeah.

-Cloth big enough, Kenny?

-I don't know. (laughing)

-Is it big enough?

Are you gonna make it

work out, Kenny?

Yeah, of course you will.

ANNA:

Yeah, I can find some swatches.

MARC:

Yeah, I just want to see,

-like, 14 or 18.

-Right, right, right.

If it's feasible with

the timing, I'm concerned.

'Cause it takes multiple steps,

you know, like,

the-the shaping and the...

So we can try, but...

They can put a man on the moon.

LA LA ANTHONY: So, Paris,

let me start with you.

I just feel so excited

to be here

with the legend Marc Jacobs.

-I just did his campaign,

and it was so incredible. -Wow.

And I'm just loving the dress

that he made for me tonight.

The dress is

absolutely stunning.

Marc, tell us about this dress.

Well, this dress, I'd say...

You know, like,

I believe in collaborat--

-Do you want me to hold this?

-Yeah, yeah.

Yeah, okay. So, you know, um,

collaboration of a sort.

So it was like a thing...

First of all,

to dress Paris Hilton

is like how the f*ck do you--

Oh, sorry--

how do you do that, right?

So I thought, like, "Well,

maybe it would be interesting

"and exciting to see her

in a black gown, you know?

'Cause it's not typical

for Paris."

So we approached her

with the idea,

and then we added the idea

of leather,

and she was all game

and everything.

And then she had some comments,

like, "I need a little sparkle,"

-and, "Could you make

this fabric here?" -Right.

And we worked together

and made it happen,

and she looks fantastic.

SOFIA:

Do you ever feel like, um,

you're the successful designer

that as a ki--

your kid self would be...

proud of?

Or, like, that... do you ever

feel like, "Oh, wow,

I'm living the life that..."

the fantasy life of...

of your kid self?

MARC:

I think, as a young person,

I believed...

that this could happen,

although I'm not really sure

I did.

You know, like, now I think,

like, "Oh, yeah, I was like,

I'm totally gonna make it."

I know sometimes, um,

before a show had happened,

I-I'd just kind of see, like,

as the lineup was formed

and the show was getting ready

to start,

and I'd kind of have these,

like, outer-body experiences--

I don't really even know

what that means--

but, like, I was looking

at myself saying, like,

"What are you doing here?"

Like, "You can't... this can't

be you having this show."

You know, like,

it was just like...

SOFIA: When you see

all the models and the clothes

-and they're coming together.

-Yeah.

And I'd have it, like,

season after season,

-so it wasn't, like...

-Oh.

...with time that went away.

It was still that same

kind of thing, like,

"I can't believe

this is happening for me."

You don't know how

to do the Hustle?

No, I do not know

how to do hustle bustle.

-You're too young. Come on.

-I'm not too young...

Do this. You have to do

the slide thing.

Follow me. Don't be so stiff.

-I can't do this.

-Relax, relax.

SOFIA: Do you ever feel

satisfied by a collection?

Like, that it turns out

the way you imagined it?

Or you never know

what it's gonna be?

MARC:

Um, I feel...

That was...

There was that one show

we did with Karole Armitage

right before the, um...

Oh, the dance one?

-Yeah. Yeah.

-Right before the pandemic?

(indistinct chatter)

MARC:

We're all sitting around,

trying to think, like,

"What is this show?"

Like, we're in the Armory

and that's all we know.

There has to be something

credible about this.

There needs to be an idea here.

Like, I just don't want,

like, a bunch of dancers.

Out of that conversation,

Karole Armitage's name

came to mind.

I mean,

she was amazing back then.

It was like if Edie Segwick

were a punk ballerina.

-Wow.

-It was very that.

We started talking

about an idea,

and then we auditioned dancers.

We saw hundreds of people.

On the second floor,

we created a dance studio,

and she started choreographing

this piece,

and they were working

around the clock.

And then we had fittings.

It was crazy.

But, see, I-I--

That kind of crazy, I love,

'cause you just feel like...

you feel like something's,

you know, happening.

You're making something,

and it's exciting and all that.

And then I was blown away

by the show.

("Orchestra Rehearsal"

by Anton Batagov playing)

And then we said,

"Oh, sh*t, we have to make all

these clothes for the dancers."

We wanted them to be dressed

in a way that was similar enough

to the vibe of the show

that you would lose the dancers

and the models.

-SOFIA: Yeah, I love that.

-You know, that they wouldn't

be, like... them versus us.

After that show,

I had such a feeling

that came over me.

I can re-feel it right now.

If this was my last show,

I'd be happy with...

Like, I'd be happy, like,

to end my whole career

on this show.

Like, it just felt--

I was really super satisfied.

Now, when I go back,

I still find fault

with some of the clothes.

-Like, some of the clothes

are problematic. -Really?

-But...

-Really? Oh, I...

-But the show...

-No one...

-...as a thing,

-(applause)

as a collaboration, as a thing,

as a seven-minute

piece of theater,

I thought, was amazing.



(cheering, applause)

-(birds chirping)

-(vehicle passes)

WOMAN:

No problem. No problem.

-MARC: Did you meet Giuseppe?

-ROMAN: I did not.

-How many years we worked

together? -30.

30 years.

We've been-- He's been working

with me on shoes

and making all the shoes

for the shows since 30 years.

I make, uh, 105, 106 dfil

with you.

-MARC: 106 dfil? Yeah. Wow.

-S.

-Mm. Why are they so big?

-Huh?

Why are they so big?

They're men?

-'Cause they're kind of

like clown shoes. -Oh.

(chime dings)

("Big Spender"

by Joseph Gershenson playing)



(chime dings)

Hey, mister, can I talk to you

for a minute?

Got a cigarette for me,

mister, huh?

Hey, mister,

do you speak Spanish?

Hey, tiger, you want to dance?

A little dance won't hurt you.

Come here, cowboy.

I want to tell you something.

Moshi, moshi,

ikaga desu-ka, baby?

Ooh, you're so tall.

MARC: So often I like the same

images as a starting point.

And the lineup

of all the dance hall girls

in "Big Spender," you know,

in the number in Sweet Charity,

it's just one of

those things, like...

-That you always...

-It's just I'll never...

-not be inspired by that image.

-(laughs)

So there's one scene, and

it's all the different dancers

against the, like, bar.

And you see them all in profile,

and they all have

these different wigs

and very powdery skin,

and they just look

kind of like broken dolls,

-in a way that only Fosse

could do. -Mm. (chuckles)

So let me get right

to the point

I don't pop my cork

for every guy I see

Hey, big spender...

MARC:

And it's so-- it's so right.

Like... like,

to make eye contact

with the audience is,

like, really disturbs people.

Or to point at them, really.

Like, you know, it's really...

And-and I just--

I thought, like...

I've looked at this

so many times, and I found it

so cool,

but I didn't realize, like,

when you broke it down,

how, like...

you know, how smart

every little gesture was.

("The Pompeii Club

(Rich Man's Frug)" playing)

The precision

of every little gesture

created a feeling of discomfort

or titillation

or whatever it was.

And he was

a really incredible man.

Like, a really-- genius.

-SOFIA: Oh, okay. Mm.

-MARC: Yeah.

(indistinct chatter)

MARC: I think she's just trying

to loosen up the models

a little bit,

get them to do what I want

-but, like, also, like, relax.

-Yeah.

-Did you tell her how... their

personalities? -Well, yeah.

I said which arms go forward

-and which arms go behind.

-Oh.

And which arms

are out at the side.

Oh, fun. (chuckles)

(indistinct chatter)

WOMAN:

Hi, everyone.

Um, Faye, I'll walk you through

so you know it.

It's a simple... simple runway,

but there is a beautiful set

that you have to work

your way around. So...

14, Diane.

15, Caren.

16, Camille.

17, Luiza.

18, Victoria.

MARC:

Um, Delilah's little...

-Yes. Yeah.

-Do y... arms out like this?

(stammering)

Uh, I think they're...

Uh, they can just be

in front like this.

-They can just be in front.

-In front of the dress?

Yeah. Yeah.

-JOSEPH: I'd say.

-MARC: Okay. Okay.

Let's see.

Delilah should keep her arms

a little bit like this,

like a ballerina.

She's got, like,

the little white tights

and that little minidress,

but not like-like that.

But just like...

Sh-She does it automatically.

-Okay. Okay.

-If you just tell her...

-What I don't want is this.

-Here she is.

-Okay. -Delilah, you're gonna be

a little bit like this, right?

-Just like a little ballerina...

-Perfect.

...c*ck waitress,

dance hall girl.

-"Can I take your order?"

-Exactly.

I think, over the years,

what's happened is the story,

to me, just becomes

a-a piece of entertainment.

Like, it's not about

the clothes at all.

Like, the clothes may be

the main part of the story,

but it's really about,

like, telling a little story

in seven minutes and, you know,

and-and that's made out

of shapes and colors

and fabrics and...

Even if it's not abstract,

there's just more of

an abstract approach to it.

Just like... whatever.

Put this together.

Tell the story.

(indistinct chatter)

She's very Mrs. Robinson,

this one. (chuckles)

But not.

Like Mrs. Robinson if I were

redoing The Graduate. (laughs)

BENJAMIN: You give me a drink,

you put on music.

Now you start opening up

your personal life to me

-and tell me your husband

won't be home for hours. -So?

Mrs. Robinson,

you're trying to seduce me.

(laughing)

("Ambient Chopin"

by Peter Murray playing)

MARC: I have some very fond

memories of watching my mother

do her makeup

when she'd go out on a date.

I could sit there for hours

and sort of watch her

as she'd choose her clothes

and put her makeup on.

She took a piece

of black velvet ribbon

and she'd scrape it with a knife

so that she could take

the pile from the black velvet

to make the lashes even thicker

and clumpier.

I just think the idea

of transformation

and creating this person

that you want to be

or show the world at any given

time is part of human nature

and the joy of being a woman,

man, or-or a person.

(music fades)

MARC:

My father...

SOFIA: He was an agent

at William Morris.

-MARC: Yeah.

-Crazy. In New York?

-MARC: Yeah. Yeah.

-Wow. And so he...

That's where he met my mother.

She was, like, doing temp work

as a receptionist.

SOFIA: And your dad was an agent

for, like, actors and stuff?

He was in Variety.

That was what he did first,

which is...

Then he went to TV.

TV. But it was

right before he died.

My favorite, favorite memories

of my father

were when he would take me

to the office.

That was, like, the most...

Like, I met the different

agents, and you...

You know, you--

I don't know. I...

Really, the best memories

I have.

SOFIA: How old were you

when you went to live

-with your grandmother?

-So, I'm always a little bit

unclear about this,

'cause I think

there was a period of time

where I was living with her

but I was still

not living with her full-time.

-You'd just stay with her?

-I stayed with her a lot.

And then I don't know

whether it was 13 or 14

that I was moved-in full-time.

I had a stepdad who was very...

not good

and, um, not a nice person.

And he didn't like her,

and she didn't like him.

He forbid me to call her

or to see her.

And I was just, like,

not having it.

(low chatter)

MARC: With Diane, one of

the things I was very sure of

was, like, a very irregular,

really exaggerated eyelash.

And so she used, like,

black nail polish,

like, so they'd have

some shine in them.

But also to make

these kind of clumps.

-Okay, so clump. Clump, clump,

clump. -Yeah. Yeah.

Lower one's still not so clumpy.

-They're very, like,

straight line-y. -Yeah.

(stammers)

Is that something you...

you think it looks better

like that?

No, it's just 'cause we have...

But then, over time,

it starts...

-They un-pinch?

-Yeah.

MARC:

You can't glue them?

-DIANE: Well, we're using

nail polish. -Yeah.

-DIANE: Yeah. -But...

'Cause you know what I mean?

-DIANE: Yes. -It's like

one, two, three, four.

-They just look like

straight lines. -Yeah. Yeah.

MARC: Whereas here,

you get those nice triangles

-and shapes.

-Yeah.

I think we have to... Like,

here they're good, aren't they?

Better.

-Better.

-It's lining on the top,

-and then I brush the underneath

into it. -Okay. Okay.

-DIANE: So it's not

super defined all over. -Okay.

DIANE: So you just get

the emphasis on the top shape.

(low chatter)

-It's like the cut crease,

no brow. -Yes. Yeah.

-Cut crease with a brow.

And brow. -Yeah. -Yeah.

And then there's no brow at all,

which was what we saw yesterday.

-Yeah.

-Yes. With nothing on the eye.

(low chatter)

MARC: See, there,

the skin and the highlight...

DIANE:

Looked great.

-Yeah. Well, I mean...

-Because you're getting the...

-Huh? -That is the beauty light,

there. -Yeah.

Beauty light.

-That's what we need

all over the world. -(chuckles)

In the weeks leading up

to the show,

it'd just get faster and faster.

So there's, like,

more that has to get done

and patterns get corrected,

and then they have to go out

to Italy to be sewn

and come back and whatever.

So it does feel like

it all accelerates in the f...

the f-four weeks before the show

and more in the two weeks

before the show. But, um...

SOFIA: Though, at this point,

you have no idea what...

MARC: I really don't have

any idea at all.

("My Love is Better"

by Annie playing)



Coming with a lie,

here we go again...

MARC:

Very often, especially lately,

you know, there's just

a type of sound that I feel

is both dramatic and-and,

like, kind of

emotionally stimulating.

And, you know, the Armory

is a very big place,

and I-I feel like

the only music that stands up

to it are, like,

-really great composers.

You know? -Dramatic. Yeah.

(music fades)

("Richter: Spring 1"

by Max Richter playing)





SOFIA: Do you remember

when you first met Marc?

Yes. I think it was

at Honmura An's, is my memory.

And I have to ask him

if this is true.

It was with Sadie Coles,

and it was when

he was interested in art.

We had dinner, and we just,

like, hit it off instantly.

I think we just, like,

had a conversation about, um,

like Pina Bausch and also, like,

just, like, weird,

unusual things

that John and I really

liked to talk about.

And he knew about

really unusual things

like Rainer Fassbinder.

-Fassbinder. -That's what

they had a big connection about.

And it was just interesting

about the eye of a designer

who was so particular--

the same eye as John,

but then John does it

through paint.

I remember I was,

like, cutting up

some drawings of--

I was making copies

of Piranesi-like ruins.

And then he's like,

"Do you want to come over

and talk to me about doing set?"

And the show was on February 14,

and it was February 1.

And then I'm making

all these Puritan girls,

like the Puritans

from, like, America,

16-something.

And he said,

"Your carriage is called

"'Puritan's Delight.'

And these girls have been

my inspiration."

And he says, "Can you bring in

what you're working on

by tomorrow?"

And so I-I think I stayed up

all night doing all this stuff.

I brought it in

as a little paper set,

and he said, "It's fantastic.

And just do whatever she says.

Make it happen."

I just think you need air.

-We want to see the neck?

-Yeah, yeah, yeah.

Probably want this

to be a little...

Yeah, I just, I just want

to see some space,

especially 'cause you're gonna

have these collars in here,

and-and I just think

it looks more beautiful.

-("Ashes to Ashes" by Warpaint)

-In such an early song

I've heard a rumor

from ground control...

MARC: But it is crazy, when

you think of the amount of work

and the amount of people

to make something

-that's seen only once.

-Yeah, for seven minutes.

-Yeah.

-Ever.

I'm happy...

MARC: I had seen this picture

of, um, some dolls

that Taboo had made,

and it was of the Supremes.

And they were just so naively

done, which was so sweet.

And then one of my favorite

videos of the Supremes

is this appearance that--

they were on

The Tennessee Ernie Ford show,

and it's Diana singing

"Reflections,"

and it's the three of them just

in these, like, spangly dresses.

And I just always have been

mesmerized by that.

Crying reflects a hurt

I can't control

'Cause although you're gone

I keep holding on

To the happy times

Ooh, when you were mine

As I peer through the window

of lost time

Looking over my yesterday

And all the love

I gave all in vain

All the love

All the love

that I've wasted...

SOFIA: I love that

the mirrors on the bags

-come from the Supremes.

-Yeah, like...

I would never have

put that together.

I mean, they weren't mirrored.

They were sequined.

-But it's still, like... it...

-Yeah.

MARC: Just if, like,

if you had to do it yourself.

("Tigerlily" by La Roux playing)

All these girls are

girls who like boys,

and I think, like, you know,

I'm not really into,

like, accessories at the moment,

like, jewelry.

So I said, "Oh, we'll just make

the boys the accessories."

("Tigerlily" continues playing)

Happy birthday, Katie!

I love you!

Tonight out on the streets

I'm gonna follow you

And tell you all about a scene

that you would k*ll for

You're gonna love what's

running right in front of you

But you won't see it

by the light of the sun.

(song ends)



(crowd chatter)

It's showtime.

We are very not linear,

in terms of the way we work.

And it's kind of like

we're always looking

for something

that we're interested in

or excited by, right?

And then you can't kind of

find inspiration that way.

You kind of have to be

doing something

and you have, like,

some kind of connection to it.

And I don't remember

at what point in the process,

but we had been talking about

all these different things--

about scale, about size--

and then something

came up somewhere,

and I saw that picture

of the table at the Broad

that I had seen and experienced

many times.

And, um, so then I looked up

Robert Therrien,

and I was just like, "Oh, well,

this folding table and chairs

just sums it up for me."

And I kind of felt very much

this kindred spirit,

'cause everyday things,

whatever "everyday"

means to you, is like

the wonder of the inspiration

you find in them,

the way he thinks,

how he gets to where he's going.

I just feel like that feels

really like what we're doing.

(indistinct chatter)

-What you doing? Came undone?

-Yeah.

So should we get Joseph

or some-somebody?

(Wali speaking indistinctly)

Yeah. Okay, so we don't want

that to happen

when you've got the jacket on.

So can we get-- Somebody

find me Joseph or-- Joseph?

Joseph, Wali's top keeps opening

-when she puts the jacket on.

-Oh, really? All right.

-Yeah, the snaps.

-Oh, okay.

So I think if you pin it

or whatever you want to do.

-Yeah, yeah.

-But when she...

As soon as she does this.

(Joseph speaks indistinctly)

-We've only got ten minutes.

-Okay, then I'll...

-But your nail polish

still looks good. -Yeah.

-Right?

-Yeah.

-I was just talking...

-Yeah, that's it.

-Like that.

-MARC: Got it.

SOFIA:

But do you always get nervous

right before, even though you've

done this a million times?

Yeah. I do, and I don't...

I don't know. It's like...

Yeah, I get really nervous.

It's, like,

such a physical thing.

-SOFIA: I can feel it for you.

-I think it's just very...

I don't know. Maybe...

Is it different for you?

Like, I feel...

I feel very fright...

Like, I-I mean, obviously,

I work to show the work.

-Yeah.

-But then showing the work

is a very frightening thing.

How many minutes left?

We have to start

in four minutes, people!

Literally four minutes!

I'm ready. Like...

but the girls aren't

quite ready.

So when the girls are ready,

then I'm like, "Oh, my God,

do we really have to wait

for the audience? Do we really?"

-Yeah. Yeah. -You know,

I want to get them dressed.

I want to get going.

And I've been, like, super

impatient on a couple of shows

where, you know, I was insisting

with KCD backstage,

like, "I don't care

if it's five-of."

-Oh. -And they're like,

"No, you've got to, like,

at least wait till 6:00."

You know.

(crowd chatter)

You have two minutes.

Two minutes.

-It's one minute, Duffy.

You gonna be okay? -Yeah.

Okay. It's 6:00.

We're starting the show.

-It's 6:00. We're starting the

show. -Making the announcement.

-Yeah, we're making

the announcement now. -Okay.

(soft chatter)

We are now late!

-Can we please start the show?

-Yes.

-Yes. Now.

-Starting the show fully.

-Now. Now.

-Starting the show. Everyone...

MARC:

We're starting the show now.

("Metamorphosis One"

by Philip Glass playing)



















Standing by. Um...

In three, two, one.

(cheering, applause)

(cheering, applause fades)

(birds chirping)

(giggles)

(chuckles)

SOFIA: How's the morning after

the show?

Um... um, it's okay.

It's okay. I'm j-- I'm...

I'm very tired.

Do you feel like

there's some catharsis

or that you work out things

from... childhood wounds

in being able to make

these imaginary worlds or...?

MARC:

Yeah, so when I was much younger

and... like,

my family fell apart--

you know, my dad died

and all this stuff--

I think I...

My solution, you know,

to all this chaos and mental

illness and all this stuff

was, like, go to your room

and make your room

into this safe place and--

where you can express yourself

and you can feel comfortable and

you can feel happy, you know.

And I do think--

I do think that that was like...

It-it may not be...

Like, that, that felt like

the beginning

of my understanding of how...

I have, like... my hiding place,

but I also have my world,

and then I also have

that place where

I can make something.

And maybe what came after was

like, okay, I can make something

and I want to share it.

SOFIA: I remember

you used to really crash.

-Yeah. -'Cause you used

to be really down,

I feel like, after a show.

Well, the down thing

will happen.

Like, um, my friend Lana,

she-she calls it

"post-art-done."

-Oh, yeah.

-As opposed to "postpartum."

I always say it's postpartum,

but that is "post-art-done."

-Yeah.

-So she changed it.

'Cause she's like,

after she makes a movie,

she's like, "There's this...

such excitement,"

but then, like-- and

you can't really explain it--

but I guess it's like

giving birth, in a sense.

There's, like, this comedown.

And no matter how you feel about

the work you've done,

you just can't avoid it,

it's gonna happen.

MARC:

Girls, it looks amazing.

You look gorgeous.

It's really great.

I started obsessing over, like,

a certain mistake yesterday

or-or something

I didn't like yesterday,

and then I was like,

"Just let it go, let it go."

But they'll catch up to me,

you know,

as I see more photos

or as I read reviews or...

I have a little distance,

you know?

Then I'll start,

like, getting...

I guess, down and a bit,

like, agitated.

My shrink always says, like,

"Obsessing over something

"that happened a week ago

isn't gonna change

what happened a week ago."

You know?

But I somehow believe that

if I obsess over it long enough,

like, it will fix itself,

you know.

And of course

I don't really believe it.

But then I think, "History tells

me I said that every time."

That's the thing about,

like, joy in work,

is that, if you can tap into

those few moments

or those few days or the,

you know, whatever it is,

then-then you kind of...

want to do it again.

You know?

Ten decisions

shape your life

You'll be aware

of five about

Seven ways

to go through school

Either you're noticed

or left out

Seven ways to get ahead

Seven reasons to drop out

When I said,

"I can see me in your eyes"

You said,

"I can see you in my bed"

That's not just friendship,

that's romance, too

You like music

we can dance to

Sit me down

Shut me up

I'll calm down

And I'll get along with you.

(song ends)

-("Line Up" by Elastica playing)

-(grunting in song)

Drivel Head wears

her glad rags

She's got her keys,

money and f*gs

I know

that her mind is made up

To get rocked

Drivel Head needs a new man

As only a drivel head can

He's a hormonal nightmare

So beware

Another victim

of line up in line

Line up in line

is all I remember

(grunting)

Oh, how their favors change

You could have been kinder

Yes, yes, line up in line

Line up in line

is all I remember

Oh, how their favors change

You could have been mine, uh

(grunting)

Drivel Head knows

all the stars

Loves to suck

their shining guitars

They've all been

right up her stairs

Do you care?

No.

(song ends)

(music fades)